@@ -66,6 +66,8 @@ object Catalog {
     ST_Y,
     ST_StartPoint,
     ST_Boundary,
+    ST_MinimumBoundingRadius,
+    ST_MinimumBoundingCircle,
     ST_EndPoint,
     ST_ExteriorRing,
     ST_GeometryN,
@@ -77,7 +79,9 @@ object Catalog {
     ST_AddPoint,
     ST_RemovePoint,
     ST_IsRing,
-    ST_FlipCoordinates
+    ST_FlipCoordinates,
+    ST_LineSubstring,
+    ST_LineInterpolatePoint
   )
 
   val aggregateExpressions: Seq[Aggregator[Geometry, Geometry, Geometry]] = Seq(
