@@ -18,9 +18,7 @@
  */
 package org.apache.spark.sql.sedona_sql.expressions
 
-import java.util
-
-import org.apache.sedona.core.geometryObjects.{Circle, GeoJSONWriterNew}
+import org.apache.sedona.core.geometryObjects.Circle
 import org.apache.sedona.core.utils.GeomUtils
 import org.apache.sedona.sql.utils.GeometrySerializer
 import org.apache.spark.internal.Logging
@@ -33,17 +31,20 @@ import org.apache.spark.sql.sedona_sql.expressions.implicits._
 import org.apache.spark.sql.types.{ArrayType, _}
 import org.apache.spark.unsafe.types.UTF8String
 import org.geotools.geometry.jts.JTS
-import org.geotools.referencing.{CRS, ReferencingFactoryFinder}
-import org.geotools.util.factory.Hints
+import org.geotools.referencing.CRS
+import org.locationtech.jts.algorithm.MinimumBoundingCircle
 import org.locationtech.jts.geom.{PrecisionModel, _}
+import org.locationtech.jts.linearref.LengthIndexedLine
 import org.locationtech.jts.operation.IsSimpleOp
+import org.locationtech.jts.operation.buffer.BufferParameters
 import org.locationtech.jts.operation.linemerge.LineMerger
 import org.locationtech.jts.operation.valid.IsValidOp
 import org.locationtech.jts.precision.GeometryPrecisionReducer
 import org.locationtech.jts.simplify.TopologyPreservingSimplifier
-import org.opengis.referencing.crs.CoordinateReferenceSystem
 import org.opengis.referencing.operation.MathTransform
+import org.wololo.jts2geojson.GeoJSONWriter
 
+import java.util
 import scala.collection.mutable.ArrayBuffer
 import scala.util.{Failure, Success, Try}
 
@@ -403,10 +404,10 @@ case class ST_IsSimple(inputExpressions: Seq[Expression])
 
 /**
   * Simplifies a geometry and ensures that the result is a valid geometry having the same dimension and number of components as the input,
-  * and with the components having the same topological relationship.  
+  * and with the components having the same topological relationship.
   * The simplification uses a maximum-distance difference algorithm similar to the Douglas-Peucker algorithm.
   *
-  * @param inputExpressions first arg is geometry 
+  * @param inputExpressions first arg is geometry
   *                         second arg is distance tolerance for the simplification(all vertices in the simplified geometry will be within this distance of the original geometry)
   */
 case class ST_SimplifyPreserveTopology(inputExpressions: Seq[Expression])
@@ -478,7 +479,7 @@ case class ST_AsGeoJSON(inputExpressions: Seq[Expression])
     inputExpressions.validateLength(1)
     val geometry = inputExpressions.head.toGeometry(input)
 
-    val writer = new GeoJSONWriterNew()
+    val writer = new GeoJSONWriter()
     UTF8String.fromString(writer.write(geometry).toString)
   }
 
@@ -657,6 +658,158 @@ case class ST_Boundary(inputExpressions: Seq[Expression])
 
 }
 
+
+case class ST_MinimumBoundingRadius(inputExpressions: Seq[Expression])
+  extends Expression with CodegenFallback {
+  private val geometryFactory = new GeometryFactory()
+
+  override def nullable: Boolean = true
+
+  override def eval(input: InternalRow): Any = {
+    inputExpressions.validateLength(1)
+    val geometry = inputExpressions.head.toGeometry(input)
+    geometry match {
+      case geom: Geometry => getMinimumBoundingRadius(geom)
+      case _ => null
+    }
+  }
+
+  private def getMinimumBoundingRadius(geom: Geometry): InternalRow = {
+    val minimumBoundingCircle = new MinimumBoundingCircle(geom)
+    val centerPoint = geometryFactory.createPoint(minimumBoundingCircle.getCentre)
+    InternalRow(centerPoint.toGenericArrayData, minimumBoundingCircle.getRadius)
+  }
+
+  override def dataType: DataType = DataTypes.createStructType(
+    Array(
+      DataTypes.createStructField("center", GeometryUDT, false),
+      DataTypes.createStructField("radius", DataTypes.DoubleType, false)
+    )
+  )
+
+  override def children: Seq[Expression] = inputExpressions
+}
+
+
+case class ST_MinimumBoundingCircle(inputExpressions: Seq[Expression])
+  extends Expression with CodegenFallback {
+
+  override def nullable: Boolean = true
+
+  override def eval(input: InternalRow): Any = {
+    inputExpressions.betweenLength(1, 2)
+    val geometry = inputExpressions.head.toGeometry(input)
+    val quadrantSegments = if (inputExpressions.length == 2)
+      inputExpressions(1).toInt(input) else BufferParameters.DEFAULT_QUADRANT_SEGMENTS
+    geometry match {
+      case geom: Geometry => getMinimumBoundingCircle(geom, quadrantSegments).toGenericArrayData
+      case _ => null
+    }
+  }
+
+  private def getMinimumBoundingCircle(geom: Geometry, quadrantSegments: Int): Geometry = {
+    val minimumBoundingCircle = new MinimumBoundingCircle(geom)
+    val centre = minimumBoundingCircle.getCentre
+    val radius = minimumBoundingCircle.getRadius
+    var circle: Geometry = null
+    if (centre == null) {
+      circle = geom.getFactory.createPolygon
+    } else {
+      circle = geom.getFactory.createPoint(centre)
+      if (radius != 0D)
+        circle = circle.buffer(radius, quadrantSegments)
+    }
+    circle
+  }
+
+  override def dataType: DataType = GeometryUDT
+
+  override def children: Seq[Expression] = inputExpressions
+}
+
+
+/**
+ * Return a linestring being a substring of the input one starting and ending at the given fractions of total 2d length.
+ * Second and third arguments are Double values between 0 and 1. This only works with LINESTRINGs.
+ *
+ * @param inputExpressions
+ */
+case class ST_LineSubstring(inputExpressions: Seq[Expression])
+  extends Expression with CodegenFallback {
+
+  override def nullable: Boolean = true
+
+  override def eval(input: InternalRow): Any = {
+    inputExpressions.validateLength(3)
+
+    val geometry = inputExpressions.head.toGeometry(input)
+    val fractions = inputExpressions.slice(1, 3).map{
+      x => x.eval(input) match {
+        case a: Decimal => a.toDouble
+        case a: Double => a
+        case a: Int => a
+      }
+    }
+
+    (geometry, fractions) match {
+      case (g:LineString, r:Seq[Double]) if r.head >= 0 && r.last <= 1 && r.last >= r.head => getLineSubstring(g, r)
+      case _ => null
+    }
+  }
+
+  private def getLineSubstring(geom: Geometry, fractions: Seq[Double]): Any = {
+    val length = geom.getLength()
+    val indexedLine = new LengthIndexedLine(geom)
+    val subLine = indexedLine.extractLine(length * fractions.head, length * fractions.last)
+    subLine.toGenericArrayData
+  }
+
+  override def dataType: DataType = GeometryUDT
+
+  override def children: Seq[Expression] = inputExpressions
+}
+
+/**
+ * Returns a point interpolated along a line. First argument must be a LINESTRING.
+ * Second argument is a Double between 0 and 1 representing fraction of
+ * total linestring length the point has to be located.
+ *
+ * @param inputExpressions
+ */
+case class ST_LineInterpolatePoint(inputExpressions: Seq[Expression])
+  extends Expression with CodegenFallback {
+
+  override def nullable: Boolean = true
+
+  override def eval(input: InternalRow): Any = {
+    inputExpressions.validateLength(2)
+
+    val geometry = inputExpressions.head.toGeometry(input)
+    val fraction: Double = inputExpressions.last.eval(input) match {
+      case a: Decimal => a.toDouble
+      case a: Double => a
+      case a: Int => a
+    }
+
+    (geometry, fraction) match {
+      case (g:LineString, f:Double) if f >= 0 && f <= 1 => getLineInterpolatePoint(g, f)
+      case _ => null
+    }
+  }
+
+  private def getLineInterpolatePoint(geom: Geometry, fraction: Double): Any = {
+    val length = geom.getLength()
+    val indexedLine = new LengthIndexedLine(geom)
+    val interPoint = indexedLine.extractPoint(length * fraction)
+    new GeometryFactory().createPoint(interPoint).toGenericArrayData
+  }
+
+  override def dataType: DataType = GeometryUDT
+
+  override def children: Seq[Expression] = inputExpressions
+}
+
+
 case class ST_EndPoint(inputExpressions: Seq[Expression])
   extends Expression with CodegenFallback {
   override def nullable: Boolean = true
