@@ -23,7 +23,9 @@ import org.apache.sedona.sql.implicits._
 import org.apache.spark.sql.functions._
 import org.apache.spark.sql.{DataFrame, Row}
 import org.geotools.geometry.jts.WKTReader2
+import org.locationtech.jts.algorithm.MinimumBoundingCircle
 import org.locationtech.jts.geom.Geometry
+import org.locationtech.jts.linearref.LengthIndexedLine
 import org.scalatest.{GivenWhenThen, Matchers}
 
 class functionTestScala extends TestBaseScala with Matchers with GeometrySample with GivenWhenThen {
@@ -850,4 +852,110 @@ class functionTestScala extends TestBaseScala with Matchers with GeometrySample
     assert(newY == oldX)
   }
 
+  it("Should pass ST_MinimumBoundingCircle") {
+    Given("Sample geometry data frame")
+    val geometryTable = Seq(
+      "POINT(0 2)",
+      "LINESTRING(0 0,0 1)"
+    ).map(geom => Tuple1(wktReader.read(geom))).toDF("geom")
+
+    When("Using ST_MinimumBoundingCircle function")
+
+    val circleTable = geometryTable.selectExpr("ST_MinimumBoundingCircle(geom) as geom")
+    val circleTableWithSeg = geometryTable.selectExpr("ST_MinimumBoundingCircle(geom, 1) as geom")
+
+    Then("Result should match List of circles")
+
+    val lineString = geometryTable.collect()(1)(0).asInstanceOf[Geometry]
+    val mbcLineString = new MinimumBoundingCircle(lineString)
+    val mbcCentre = lineString.getFactory.createPoint(mbcLineString.getCentre)
+
+    circleTable.selectExpr("ST_AsText(geom)")
+      .as[String].collect().toList should contain theSameElementsAs List(
+      "POINT (0 2)",
+      mbcCentre.buffer(mbcLineString.getRadius, 8).toText
+    )
+
+    circleTableWithSeg.selectExpr("ST_AsText(geom)")
+      .as[String].collect().toList should contain theSameElementsAs List(
+      "POINT (0 2)",
+      mbcCentre.buffer(mbcLineString.getRadius, 1).toText
+    )
+  }
+
+  it("Should pass ST_MinimumBoundingRadius") {
+    Given("Sample geometry data frame")
+    val geometryTable = Seq(
+      "POINT (0 1)",
+      "LINESTRING(1 1,0 0, -1 1)",
+      "POLYGON((1 1,0 0, -1 1, 1 1))"
+    ).map(geom => Tuple1(wktReader.read(geom))).toDF("geom")
+
+    When("Using ST_MinimumBoundingRadius function")
+
+    val radiusTable = geometryTable.selectExpr("ST_MinimumBoundingRadius(geom) as tmp").select("tmp.*")
+
+    Then("Result should match List of centers and radius")
+
+    radiusTable.selectExpr("ST_AsText(center)")
+      .as[String].collect().toList should contain theSameElementsAs List(
+      "POINT (0 1)",
+      "POINT (0 1)",
+      "POINT (0 1)"
+    )
+
+    radiusTable.selectExpr("radius")
+      .as[Double].collect().toList should contain theSameElementsAs List(0, 1, 1)
+  }
+
+  it ("Should pass ST_LineSubstring") {
+    Given("Sample geometry dataframe")
+    val geometryTable = Seq(
+      "LINESTRING(25 50, 100 125, 150 190)"
+    ).map(geom => Tuple1(wktReader.read(geom))).toDF("geom")
+
+    When("Using ST_LineSubstring")
+
+    val substringTable = geometryTable.selectExpr("ST_LineSubstring(geom, 0.333, 0.666) as subgeom")
+
+    Then("Result should match")
+
+    val lineString = geometryTable.collect()(0)(0).asInstanceOf[Geometry]
+    val indexedLineString = new LengthIndexedLine(lineString)
+    val substring = indexedLineString.extractLine(lineString.getLength() * 0.333, lineString.getLength() * 0.666)
+
+    substringTable.selectExpr("ST_AsText(subgeom)")
+      .as[String].collect() should contain theSameElementsAs
+      List(
+        substring.toText
+      )
+  }
+
+  it ("Should pass ST_LineInterpolatePoint") {
+    Given("Sample geometry dataframe")
+    val geometryTable = Seq(
+      "LINESTRING(25 50, 100 125, 150 190)",
+      "LINESTRING(1 2 3, 4 5 6, 6 7 8)"
+    ).map(geom => Tuple1(wktReader.read(geom))).toDF("geom")
+
+    When("Using ST_LineInterpolatePoint")
+
+    val interpolatedPointTable = geometryTable.selectExpr("ST_LineInterpolatePoint(geom, 0.50) as interpts")
+
+    Then("Result should match")
+
+    val lineString2D = geometryTable.collect()(0)(0).asInstanceOf[Geometry]
+    val lineString3D = geometryTable.collect()(1)(0).asInstanceOf[Geometry]
+
+    val interPoint2D = new LengthIndexedLine(lineString2D).extractPoint(lineString2D.getLength() * 0.5)
+    val interPoint3D = new LengthIndexedLine(lineString3D).extractPoint(lineString3D.getLength() * 0.5)
+
+    interpolatedPointTable.selectExpr("ST_AsText(interpts)")
+      .as[String].collect() should contain theSameElementsAs
+      List(
+        lineString2D.getFactory.createPoint(interPoint2D).toText,
+        lineString2D.getFactory.createPoint(interPoint3D).toText
+      )
+  }
+
 }
